@@ -110,6 +110,7 @@ class FileSystemManager(object):
                  'gpt': '8200',
                  'label': '',
                  'ssd': [],
+                 'auto': False,
                  'msdos': '82'},
         'uefi': {'defaultopt': defaultOpt,
                  'format': '/usr/sbin/mkfs.vfat',
@@ -118,6 +119,7 @@ class FileSystemManager(object):
                  'label': '-n {labelname}',
                  'msdos': '0b',
                  'ssd': [],
+                 'auto': False,
                  'type': ['hdd']},
         'vfat': {'defaultopt': defaultOpt,
                  'format': '/usr/sbin/mkfs.vfat',
@@ -125,6 +127,7 @@ class FileSystemManager(object):
                  'gpt': '0700',
                  'label': '-n {labelname}',
                  'msdos': '0b',
+                 'auto': False,
                  'ssd': ['discard'],
                  'type': ['flash']},
         'ntfs': {'defaultopt': defaultOpt,
@@ -133,6 +136,7 @@ class FileSystemManager(object):
                  'gpt': '8300',
                  'label': '-L {labelname}',
                  'msdos': '7',
+                 'auto': False,
                  'ssd': [],
                  'compatible': ['ntfs-3g']},
         'ntfs-3g': {'defaultopt': defaultOpt,
@@ -141,6 +145,7 @@ class FileSystemManager(object):
                     'gpt': '8300',
                     'label': '-L {labelname}',
                     'ssd': [],
+                    'auto': False,
                     'msdos': '7',
                     'compatible': ['ntfs']}}
 
@@ -160,6 +165,8 @@ class FileSystemManager(object):
     defaultFS = {
         'hdd': ("ext4"
                 if path.exists(supportFS['ext4']['format']) else
+                "btrfs"
+                if path.exists(supportFS['btrfs']['format']) else
                 "reiserfs"
                 if path.exists(supportFS['reiserfs']['format']) else
                 "ext3"),
