@@ -27,6 +27,7 @@ from time import sleep
 from calculate.core.server.func import MethodsInterface
 from calculate.core.server.admin import Admins
 from calculate.lib.utils.mount import isMount
+from calculate.lib.utils.system import SystemPath
 from calculate.lib.utils.files import (pathJoin,
                                        process, listDirectory, writeFile,
                                        checkUtils, readFile, find, copyWithPath,
@@ -500,8 +501,8 @@ class Install(MethodsInterface):
         Выполнить выбор opengl для текущего видеодрайвера
         """
         default_gl = "xorg-x11"
-        path_gl_modules = path.join(self.clVars.Get('cl_chroot_path'),
-                                    'usr/lib/opengl')
+        path_gl_modules = SystemPath(
+            self.clVars.Get('cl_chroot_path')).libopengl
         open_gl_env = path.join(self.clVars.Get('cl_chroot_path'),
                                 'etc/env.d/000opengl')
 
